"""Module to store constants used in the application."""

from kivy.lang.builder import Builder

PRIMARY_COLOR = '#68B7FF'
SECONDARY_COLOR = '#363F4B'
SECONDARY_COLOR_LIGHT = '#ABA7A7'
TEXT_COLOR = '#FFFFFF'

INFO_COLOR = '#2196F3'
DANGER_COLOR = '#FF3F51'
WARNING_COLOR = '#FFC107'
SUCCESS_COLOR = '#03F7AE'

Builder.load_string(
    f"""
#:set UBO_GUI_PRIMARY_COLOR '{PRIMARY_COLOR}'
#:set UBO_GUI_SECONDARY_COLOR '{SECONDARY_COLOR}'
#:set UBO_GUI_SECONDARY_COLOR_LIGHT '{SECONDARY_COLOR_LIGHT}'
#:set UBO_GUI_TEXT_COLOR '{TEXT_COLOR}'

#:set UBO_GUI_INFO_COLOR '{INFO_COLOR}'
#:set UBO_GUI_DANGER_COLOR '{DANGER_COLOR}'
#:set UBO_GUI_WARNING_COLOR '{WARNING_COLOR}'
#:set UBO_GUI_SUCCESS_COLOR '{SUCCESS_COLOR}'
""",
)
